package cn.iocoder.yudao.module.inspection.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import cn.iocoder.yudao.module.inspection.entity.InspectionNews;
import cn.iocoder.yudao.module.inspection.entity.InspectionNewsAssociation;

import java.util.List;


/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2023-08-07
 */
public interface IInspectionNewsAssociationService  extends IService<InspectionNewsAssociation>
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public InspectionNewsAssociation selectInspectionNewsAssociationById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param inspectionNewsAssociation 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public IPage<InspectionNewsAssociation> selectInspectionNewsAssociationList(Page<InspectionNewsAssociation> page, InspectionNewsAssociation inspectionNewsAssociation);

    /**
     * 新增【请填写功能名称】
     *
     * @param inspectionNewsAssociation 【请填写功能名称】
     * @return 结果
     */
    public int insertInspectionNewsAssociation(InspectionNewsAssociation inspectionNewsAssociation);

    /**
     * 修改【请填写功能名称】
     *
     * @param inspectionNewsAssociation 【请填写功能名称】
     * @return 结果
     */
    public int updateInspectionNewsAssociation(InspectionNewsAssociation inspectionNewsAssociation);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteInspectionNewsAssociationByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteInspectionNewsAssociationById(Long id);
    Long getStatus(Long newsId,Long userId,String type);
}
